pub enum Input<'machine> {
Bound {
request: &'machine dyn Request,
bound_client: BoundClient<'static>,
},
Extended(Extensions),
Negotiated {
pre_grant: PreGrant,
state: Option<String>,
},
Finished,
None,
}Expand description
Input injected by the executor into the state machine.
Variants
Bound
Binding of the client succeeded
Fields

request: &'machine dyn RequestRequest is given again to make some additional check that need bound client to run

bound_client: BoundClient<'static>The bound client
Extended(Extensions)
Extension succeeded
Negotiated
Negotiation done
Fields
Finished
We’re done
None
Advance without input as far as possible, or just retrieve the output again.