Struct oxide_auth::code_grant::backend::GuardRef [] [src]

pub struct GuardRef<'a> { /* fields omitted */ }

Methods

impl<'a> GuardRef<'a>
[src]

[src]

[src]

Construct a guard from an issuer backend and a choice of scopes. A grant need only have ONE of the scopes to access the resource but each scope can require multiple subscopes.