Module oxide_auth::code_grant::frontend [] [src]

General algorithms for frontends.

The frontend is concerned with executing the abstract behaviours given by the backend in terms of the actions of the frontend types. This means translating Redirect errors to the correct Redirect http response for example or optionally sending internal errors to loggers.

To ensure the adherence to the oauth2 rfc and the improve general implementations, some control flow of incoming packets is specified here instead of the frontend implementations. Instead, traits are offered to make this compatible with other frontends. In theory, this makes the frontend pluggable which could improve testing.

Structs

AccessFlow
AuthenticationRequest

Sent to the OwnerAuthorizer to request owner permission.

AuthorizationFlow
GrantFlow
PreparedAccess
PreparedAuthorization
PreparedGrant

Enums

Authentication

Answer from OwnerAuthorizer to indicate the owners choice.

OAuthError

Traits

OwnerAuthorizer
WebRequest
WebResponse