Trait oxide_auth::code_grant::frontend::WebRequest [] [src]

pub trait WebRequest {
    type Response: WebResponse;
    fn query(&mut self) -> Result<HashMap<String, Vec<String>>, ()>;
fn urlbody(&mut self) -> Result<&HashMap<String, Vec<String>>, ()>;
fn authheader(&mut self) -> Result<Option<Cow<str>>, ()>; }

Associated Types

Required Methods

Retrieve a parsed version of the url query. An Err return value indicates a malformed query or an otherwise malformed WebRequest. Note that an empty query should result in Ok(HashMap::new()) instead of an Err.

Retriev the parsed application/x-form-urlencoded body of the request. An Err value indicates a malformed body or a different Content-Type.

Contents of the authorization header or none if none exists. An Err value indicates a malformed header or request.

Implementations on Foreign Types

impl<'a, 'b> WebRequest for Request<'a, 'b>
[src]

[src]

[src]

[src]

Implementors