Trait oxide_auth::code_grant::TokenGenerator [] [src]

pub trait TokenGenerator {
    fn generate(&self, _: &Grant) -> String;
}

Generic token for a specific grant.

The interface may be reused for authentication codes, bearer tokens and refresh tokens.

Required Methods

For example sign a grant or generate a random token. The exact guarantees and uses depend on the specific implementation.

Implementors