ResourceFlow

Struct ResourceFlow 

pub struct ResourceFlow<E, R>
where E: Endpoint<R>, R: WebRequest,
{ /* private fields */ }
Guards resources by requiring OAuth authorization.

Implementations

Source

impl<E, R> ResourceFlow<E, R>
where E: Endpoint<R>, R: WebRequest,

pub fn prepare(endpoint: E) -> Result<Self, E::Error>

Check that the endpoint supports the necessary operations for handling requests.

Binds the endpoint to a particular type of request that it supports, for many implementations this is probably single type anyways.

Panics

Indirectly execute may panic when this flow is instantiated with an inconsistent endpoint, for details see the documentation of Endpoint and execute. For consistent endpoints, the panic is instead caught as an error here.

pub fn execute( &mut self, request: R, ) -> Result<Grant, Result<R::Response, E::Error>>

Use the checked endpoint to check for authorization for a resource.

Panics

When the issuer returned by the endpoint is suddenly None when previously it was Some(_).