Extensions

Struct Extensions 

pub struct Extensions { /* private fields */ }
Links one or several GrantExtension instances to their respective data.

This also serves as a clean interface for both frontend and backend to reliably and conveniently manipulate or query the stored data sets.

Implementations

Source

impl Extensions

pub fn new() -> Extensions

Create a new extension store.

pub fn set(&mut self, extension: &dyn GrantExtension, content: Value)

Set the stored content for a GrantExtension instance.

pub fn set_raw(&mut self, identifier: String, content: Value)

Set content for an extension without a corresponding instance.

pub fn remove(&mut self, extension: &dyn GrantExtension) -> Option<Value>

Retrieve the stored data of an instance.

This removes the data from the store to avoid possible mixups and to allow a copyless retrieval of bigger data strings.

pub fn public(&self) -> PublicExtensions<'_>

Iterate of the public extensions whose presence and content is not secret.

pub fn private(&self) -> PrivateExtensions<'_>

Iterate of the private extensions whose presence and content must not be revealed.