Struct oxide_auth::code_grant::backend::ErrorDescription
[−]
[src]
pub struct ErrorDescription { /* fields omitted */ }Simple wrapper around AccessTokenError to imbue the type with addtional json functionality. In addition this enforces backend specific behaviour for obtaining or handling the access error.