Trait oxide_auth::code_grant::frontend::WebRequest
[−]
[src]
pub trait WebRequest {
type Response: WebResponse;
fn query(&mut self) -> Result<HashMap<String, Vec<String>>, ()>;
fn urlbody(&mut self) -> Result<&HashMap<String, Vec<String>>, ()>;
fn authheader(&mut self) -> Result<Option<Cow<str>>, ()>;
}
Associated Types
type Response: WebResponse
Required Methods
fn query(&mut self) -> Result<HashMap<String, Vec<String>>, ()>
Retrieve a parsed version of the url query. An Err return value indicates a malformed query
or an otherwise malformed WebRequest. Note that an empty query should result in
Ok(HashMap::new()) instead of an Err.
fn urlbody(&mut self) -> Result<&HashMap<String, Vec<String>>, ()>
Retriev the parsed application/x-form-urlencoded body of the request. An Err value
indicates a malformed body or a different Content-Type.
fn authheader(&mut self) -> Result<Option<Cow<str>>, ()>
Contents of the authorization header or none if none exists. An Err value indicates a malformed header or request.