Struct oxide_auth::code_grant::Scope
[−]
[src]
pub struct Scope { /* fields omitted */ }Scope of a bearer token, a set of scope-tokens encoded with separation by spaces
Methods
impl Scope[src]
fn privileged_to(&self, rhs: &Scope) -> bool[src]
Determines if this scope has enough privileges to access some resource requiring the scope
on the right side. This operation is equivalent to comparision via <=.