pub struct ResourceFlow<E, R>where
E: Endpoint<R>,
R: WebRequest,{ /* private fields */ }Expand description
Guards resources by requiring OAuth authorization.
Implementations
Sourceimpl<E, R> ResourceFlow<E, R>where
E: Endpoint<R>,
R: WebRequest,
impl<E, R> ResourceFlow<E, R>where
E: Endpoint<R>,
R: WebRequest,
Sourcepub fn prepare(endpoint: E) -> Result<Self, E::Error>
pub fn prepare(endpoint: E) -> Result<Self, E::Error>
Check that the endpoint supports the necessary operations for handling requests.
Binds the endpoint to a particular type of request that it supports, for many implementations this is probably single type anyways.
Panics
Indirectly execute may panic when this flow is instantiated with an inconsistent
endpoint, for details see the documentation of Endpoint and execute. For
consistent endpoints, the panic is instead caught as an error here.